@@ -12,13 +12,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import pecan
 from oslo_log import log as logging
+import pecan
 
-from designate import utils
 from designate.api.v2.controllers import rest
-from designate.i18n import _LI
-
+from designate import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -40,7 +38,7 @@ class AbandonController(rest.RestController):
         zone = self.central_api.delete_zone(context, zone_id)
         if zone.deleted_at:
             response.status_int = 204
-            LOG.info(_LI("Abandoned %(zone)s"), {'zone': zone})
+            LOG.info("Abandoned %(zone)s", {'zone': zone})
         else:
             response.status_int = 500
 
