@@ -16,10 +16,10 @@
 import itertools
 
 import dns.rdata
-import dns.rdatatype
 import dns.rdataclass
-from oslo_config import cfg
+import dns.rdatatype
 from oslo_concurrency import lockutils
+from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate.backend.agent_backend import base
@@ -126,7 +126,8 @@ class DenominatorBackend(base.AgentBackend):
 
         # Use SOA TTL as zone default TTL
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
-        rname = soa_record.items[0].rname.derelativize(origin=zone.origin)
+        rname = list(soa_record.items)[0].rname.derelativize(
+                                                    origin=zone.origin)
 
         # Lock zone to prevent concurrent changes.
         with self._sync_zone(zone.origin):
@@ -159,7 +160,8 @@ class DenominatorBackend(base.AgentBackend):
             zone_name = zone_name.decode('utf-8')
 
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
-        rname = soa_record.items[0].rname.derelativize(origin=zone.origin)
+        rname = list(soa_record.items)[0].rname.derelativize(
+                                                    origin=zone.origin)
 
         with self._sync_zone(zone.origin):
             # Update zone with a new parameters
