@@ -19,11 +19,12 @@ from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
 import designate.conf
+from designate import heartbeat_emitter
 from designate import hookpoints
 from designate import service
+from designate.sink import service as sink_service
 from designate import utils
 from designate import version
-from designate.sink import service as sink_service
 
 
 CONF = designate.conf.CONF
@@ -38,7 +39,7 @@ def main():
     hookpoints.log_hook_setup()
 
     server = sink_service.Service()
-    heartbeat = service.Heartbeat(server.service_name)
+    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
     service.serve(server, workers=CONF['service:sink'].workers)
     heartbeat.start()
     service.wait()
