@@ -13,6 +13,9 @@
 # under the License.
 
 from oslo_middleware import cors
+from oslo_policy import opts as policy_opts
+
+import designate.conf
 
 
 def set_defaults():
@@ -34,3 +37,8 @@ def set_defaults():
                        'PATCH',
                        'HEAD']
     )
+    # TODO(gmann): Remove setting the default value of config policy_file
+    # once oslo_policy change the default value to 'policy.yaml'.
+    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+    DEFAULT_POLICY_FILE = 'policy.yaml'
+    policy_opts.set_defaults(designate.conf.CONF, DEFAULT_POLICY_FILE)
