@@ -13,14 +13,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import itertools
 import copy
+import itertools
 
+from keystoneauth1.access import service_catalog as ksa_service_catalog
+from keystoneauth1 import plugin
 from oslo_context import context
 from oslo_log import log as logging
 
 from designate import policy
-from designate.i18n import _LI
 
 LOG = logging.getLogger(__name__)
 
@@ -30,25 +31,25 @@ class DesignateContext(context.RequestContext):
     _all_tenants = False
     _hide_counts = False
     _abandon = None
-    original_tenant = None
+    original_project_id = None
     _edit_managed_records = False
     _client_addr = None
     FROM_DICT_EXTRA_KEYS = [
-        'original_tenant', 'service_catalog', 'all_tenants', 'abandon',
+        'original_project_id', 'service_catalog', 'all_tenants', 'abandon',
         'edit_managed_records', 'tsigkey_id', 'hide_counts', 'client_addr',
     ]
 
     def __init__(self, service_catalog=None, all_tenants=False, abandon=None,
-                 tsigkey_id=None, original_tenant=None,
+                 tsigkey_id=None, original_project_id=None,
                  edit_managed_records=False, hide_counts=False,
-                 client_addr=None, **kwargs):
-
+                 client_addr=None, user_auth_plugin=None, **kwargs):
         super(DesignateContext, self).__init__(**kwargs)
 
+        self.user_auth_plugin = user_auth_plugin
         self.service_catalog = service_catalog
         self.tsigkey_id = tsigkey_id
 
-        self.original_tenant = original_tenant
+        self.original_project_id = original_project_id
 
         self.all_tenants = all_tenants
         self.abandon = abandon
@@ -67,22 +68,30 @@ class DesignateContext(context.RequestContext):
         # Override the user_identity field to account for TSIG. When a TSIG key
         # is used as authentication e.g. via MiniDNS, it will act as a form
         # of "user",
-        user = self.user or '-'
+        user = self.user_id or '-'
 
-        if self.tsigkey_id and not self.user:
+        if self.tsigkey_id and not self.user_id:
             user = 'TSIG:%s' % self.tsigkey_id
 
         user_idt = (
-            self.user_idt_format.format(user=user,
-                                        tenant=self.tenant or '-',
-                                        domain=self.domain or '-',
-                                        user_domain=self.user_domain or '-',
-                                        p_domain=self.project_domain or '-'))
+            self.user_idt_format.format(
+                user=user,
+                # TODO(johnsom) Remove tenant once oslo.context>=4.0.0 is
+                #               the lower bound version.
+                tenant=self.project_id or '-',
+                project_id=self.project_id or '-',
+                domain=self.domain_id or '-',
+                user_domain=self.user_domain_id or '-',
+                p_domain=self.project_domain_id or '-')
+        )
 
         # Update the dict with Designate specific extensions and overrides
         d.update({
+            # TODO(johnsom) Remove project_id once oslo.context>=4.0.0 is
+            #               the lower bound version.
+            'project_id': self.project_id,
             'user_identity': user_idt,
-            'original_tenant': self.original_tenant,
+            'original_project_id': self.original_project_id,
             'service_catalog': self.service_catalog,
             'all_tenants': self.all_tenants,
             'abandon': self.abandon,
@@ -104,6 +113,8 @@ class DesignateContext(context.RequestContext):
 
         # NOTE(kiall): Ugly - required to match http://tinyurl.com/o3y8qmw
         context.roles.append('admin')
+        if policy.enforce_new_defaults():
+            context.system_scope = 'all'
 
         if show_deleted is not None:
             context.show_deleted = show_deleted
@@ -116,20 +127,21 @@ class DesignateContext(context.RequestContext):
 
         return context
 
-    def sudo(self, tenant):
+    def sudo(self, project_id):
 
         policy.check('use_sudo', self)
 
-        LOG.info(_LI('Accepted sudo from user %(user)s to tenant %(tenant)s'),
-                 {'user': self.user, 'tenant': tenant})
-        self.original_tenant = self.tenant
-        self.tenant = tenant
+        LOG.info('Accepted sudo from user %(user)s to project_id %(project)s',
+                 {'user': self.user_id, 'project': project_id})
+        self.original_project_id = self.project_id
+        self.project_id = project_id
 
     @classmethod
     def get_admin_context(cls, **kwargs):
         # TODO(kiall): Remove Me
         kwargs['is_admin'] = True
-        kwargs['roles'] = ['admin']
+        kwargs['roles'] = ['admin', 'reader']
+        kwargs['system_scope'] = 'all'
 
         return cls(None, **kwargs)
 
@@ -194,6 +206,49 @@ class DesignateContext(context.RequestContext):
     def client_addr(self, value):
         self._client_addr = value
 
+    def get_auth_plugin(self):
+        if self.user_auth_plugin:
+            return self.user_auth_plugin
+        else:
+            return _ContextAuthPlugin(self.auth_token, self.service_catalog)
+
+
+class _ContextAuthPlugin(plugin.BaseAuthPlugin):
+    """A keystoneauth auth plugin that uses the values from the Context.
+    Ideally we would use the plugin provided by auth_token middleware however
+    this plugin isn't serialized yet so we construct one from the serialized
+    auth data.
+    """
+    def __init__(self, auth_token, sc):
+        super(_ContextAuthPlugin, self).__init__()
+
+        self.auth_token = auth_token
+        self.service_catalog = ksa_service_catalog.ServiceCatalogV2(sc)
+
+    def get_token(self, *args, **kwargs):
+        return self.auth_token
+
+    def get_endpoint(self, session, **kwargs):
+        endpoint_data = self.get_endpoint_data(session, **kwargs)
+        if not endpoint_data:
+            return None
+        return endpoint_data.url
+
+    def get_endpoint_data(self, session,
+                          endpoint_override=None,
+                          discover_versions=True,
+                          **kwargs):
+        urlkw = {}
+        for k in ('service_type', 'service_name', 'service_id', 'endpoint_id',
+                  'region_name', 'interface'):
+            if k in kwargs:
+                urlkw[k] = kwargs[k]
+
+        endpoint = endpoint_override or self.service_catalog.url_for(**urlkw)
+        return super(_ContextAuthPlugin, self).get_endpoint_data(
+            session, endpoint_override=endpoint,
+            discover_versions=discover_versions, **kwargs)
+
 
 def get_current():
     return context.get_current()
