@@ -13,18 +13,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import time
 import socket
+import time
 
-import eventlet
 import dns
-import dns.rdataclass
-import dns.rdatatype
 import dns.exception
 import dns.flags
-import dns.rcode
 import dns.message
 import dns.opcode
+import dns.rcode
+import dns.rdataclass
+import dns.rdatatype
+import eventlet
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -123,7 +123,7 @@ class NotifyEndpoint(base.BaseEndpoint):
                     and response.answer[0].rdtype == dns.rdatatype.SOA:
                 # parse the SOA response and get the serial number
                 rrset = response.answer[0]
-                actual_serial = rrset.to_rdataset().items[0].serial
+                actual_serial = list(rrset.to_rdataset().items)[0].serial
 
             # TODO(vinod): Account for serial number wrap around. Unix
             # timestamps are used where Designate is primary, but secondary
