@@ -11,10 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import six
-
-from designate.objects.adapters.api_v2 import base
 from designate import objects
+from designate.objects.adapters.api_v2 import base
 
 
 class ZoneAttributeAPIv2Adapter(base.APIv2Adapter):
@@ -43,7 +41,7 @@ class ZoneAttributeAPIv2Adapter(base.APIv2Adapter):
 
     @classmethod
     def _parse_object(cls, values, object, *args, **kwargs):
-        for key in six.iterkeys(values):
+        for key in values.keys():
             object.key = key
             object.value = values[key]
 
@@ -71,7 +69,7 @@ class ZoneAttributeListAPIv2Adapter(base.APIv2Adapter):
             value = cls.get_object_adapter(
                 cls.ADAPTER_FORMAT,
                 object).render(cls.ADAPTER_FORMAT, object, *args, **kwargs)
-            for key in six.iterkeys(value):
+            for key in value.keys():
                 r_list[key] = value[key]
 
         return r_list
