@@ -15,11 +15,11 @@
 # under the License.
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_policy import policy
 from oslo_policy import opts
+from oslo_policy import policy
 
-from designate import exceptions
 from designate.common import policies
+from designate import exceptions
 
 
 CONF = cfg.CONF
@@ -73,10 +73,17 @@ def init(default_rule=None, policy_file=None):
 
 
 def check(rule, ctxt, target=None, do_raise=True, exc=exceptions.Forbidden):
-    creds = ctxt.to_dict()
+    if enforce_new_defaults():
+        creds = ctxt.to_policy_values()
+    else:
+        creds = ctxt.to_dict()
     target = target or {}
     try:
         result = _ENFORCER.enforce(rule, target, creds, do_raise, exc)
+    except policy.InvalidScope:
+        result = False
+        if do_raise:
+            raise exceptions.InvalidTokenScope
     except Exception:
         result = False
         raise
@@ -93,3 +100,9 @@ def check(rule, ctxt, target=None, do_raise=True, exc=exceptions.Forbidden):
             LOG.info("Policy check failed for rule '%(rule)s' "
                      "on target %(target)s",
                      {'rule': rule, 'target': repr(target)}, extra=extra)
+
+
+def enforce_new_defaults():
+    if CONF.get('oslo_policy'):
+        return CONF['oslo_policy'].get('enforce_new_defaults', False)
+    return False
