@@ -27,10 +27,13 @@ LOG = logging.getLogger(__name__)
 
 
 class Service(service.Service):
-    def __init__(self, threads=None):
-        super(Service, self).__init__(threads=threads)
+    def __init__(self):
+        super(Service, self).__init__(
+            self.service_name, threads=cfg.CONF['service:sink'].threads
+        )
 
         # Initialize extensions
+        self._server = None
         self.handlers = self._init_extensions()
         self.subscribers = self._get_subscribers()
 
@@ -38,7 +41,8 @@ class Service(service.Service):
     def service_name(self):
         return 'sink'
 
-    def _init_extensions(self):
+    @staticmethod
+    def _init_extensions():
         """Loads and prepares all enabled extensions"""
 
         enabled_notification_handlers = \
@@ -68,22 +72,25 @@ class Service(service.Service):
 
         # TODO(ekarlso): Change this is to endpoint objects rather then
         # ourselves?
-        self._server = rpc.get_notification_listener(
-            targets, [self],
-            pool=cfg.CONF['service:sink'].listener_pool_name)
-
         if targets:
+            self._server = rpc.get_notification_listener(
+                targets, [self],
+                pool=cfg.CONF['service:sink'].listener_pool_name
+            )
             self._server.start()
 
-    def stop(self):
+    def stop(self, graceful=True):
         # Try to shut the connection down, but if we get any sort of
         # errors, go ahead and ignore them.. as we're shutting down anyway
         try:
-            self._server.stop()
-        except Exception:
-            pass
+            if self._server:
+                self._server.stop()
+        except Exception as e:
+            LOG.warning(
+                'Unable to gracefully stop the notification listener: %s', e
+            )
 
-        super(Service, self).stop()
+        super(Service, self).stop(graceful)
 
     def _get_targets(self):
         """
