@@ -15,13 +15,10 @@
 # under the License.
 import abc
 
-import six
-
 from designate.plugin import DriverPlugin
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Storage(DriverPlugin):
+class Storage(DriverPlugin, metaclass=abc.ABCMeta):
 
     """Base class for storage plugins"""
     __plugin_ns__ = 'designate.storage'
@@ -325,8 +322,8 @@ class Storage(DriverPlugin):
         """
 
     @abc.abstractmethod
-    def find_recordsets(self, context, criterion=None,
-                        marker=None, limit=None, sort_key=None, sort_dir=None):
+    def find_recordsets(self, context, criterion=None, marker=None, limit=None,
+                        sort_key=None, sort_dir=None, force_index=False):
         """
         Find RecordSets.
 
@@ -761,8 +758,36 @@ class Storage(DriverPlugin):
         :param zone_export_id: Delete a Zone Export via ID
         """
 
-    def ping(self, context):
-        """Ping the Storage connection"""
-        return {
-            'status': None
-        }
+    @abc.abstractmethod
+    def find_service_statuses(self, context, criterion=None, marker=None,
+                            limit=None, sort_key=None, sort_dir=None):
+        """
+        Retrieve status for services
+
+        :param context: RPC Context.
+        :param criterion: Criteria to filter by.
+        :param marker: Resource ID from which after the requested page will
+                       start after
+        :param limit: Integer limit of objects of the page size after the
+                      marker
+        :param sort_key: Key from which to sort after.
+        :param sort_dir: Direction to sort after using sort_key.
+        """
+
+    @abc.abstractmethod
+    def find_service_status(self, context, criterion):
+        """
+        Find a single Service Status.
+
+        :param context: RPC Context.
+        :param criterion: Criteria to filter by.
+        """
+
+    @abc.abstractmethod
+    def update_service_status(self, context, service_status):
+        """
+        Update the Service status for a service.
+
+        :param context: RPC Context.
+        :param service_status: Set the status for a service.
+        """
