@@ -18,29 +18,28 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import absolute_import
+from unittest import mock
 
+from contextlib import contextmanager
 import logging as std_logging
 import os
 import random
 import shutil
 import tempfile
-from contextlib import contextmanager
 
 import fixtures
-import mock
-import tooz.coordination
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import importutils
+import tooz.coordination
 
-import designate.service
-import designate.utils
 from designate import network_api
+from designate.network_api import fake as fake_network_api
 from designate import policy
 from designate import rpc
-from designate.network_api import fake as fake_network_api
+import designate.service
 from designate.sqlalchemy import utils as sqlalchemy_utils
+import designate.utils
 
 """Test fixtures
 """
