@@ -18,8 +18,8 @@ import itertools
 from oslo_log import log as logging
 from webtest import TestApp
 
-from designate.api import v2 as api_v2
 from designate.api import middleware
+from designate.api import v2 as api_v2
 from designate.tests.test_api import ApiTestCase
 
 
@@ -54,8 +54,8 @@ class ApiV2TestCase(ApiTestCase):
 
         # Inject the TestContext middleware
         self.app = middleware.TestContextMiddleware(
-            self.app, self.admin_context.tenant,
-            self.admin_context.tenant)
+            self.app, self.admin_context.project_id,
+            self.admin_context.project_id)
 
         # Obtain a test client
         self.client = TestApp(self.app)
