@@ -12,7 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import six
 
 from designate.tests.test_api.test_v2 import ApiV2TestCase
 
@@ -85,7 +84,7 @@ class ApiV2TldsTest(ApiV2TestCase):
         # We should start with 0 tlds
         self.assertEqual(0, len(response.json['tlds']))
 
-        data = [self.create_tld(name='tld%s.' % i) for i in 'abcdefghijklmn']
+        data = [self.create_tld(name='tld%s' % i) for i in 'abcdefghijklmn']
         self._assert_paging(data, '/tlds', key='tlds')
 
     def test_get_tld(self):
@@ -181,7 +180,7 @@ class ApiV2TldsTest(ApiV2TestCase):
         correct_results = [1, 2]
 
         for get_url, correct_result in \
-                six.moves.zip(get_urls, correct_results):
+                zip(get_urls, correct_results):
 
             self.policy({'find_tlds': '@'})
             response = self.client.get(get_url)
