@@ -25,12 +25,11 @@ import dns.zone
 import eventlet
 from oslo_config import cfg
 import oslotest.base
-from dns import zone as dnszone
 
-import designate.tests
 from designate import dnsutils
 from designate import exceptions
 from designate import objects
+import designate.tests
 
 CONF = cfg.CONF
 
@@ -97,7 +96,7 @@ class TestUtils(designate.tests.TestCase):
     def test_from_dnspython_zone(self):
         zone_file = self.get_zonefile_fixture()
 
-        dnspython_zone = dnszone.from_text(
+        dnspython_zone = dns.zone.from_text(
             zone_file,
             relativize=False,
             check_origin=False
@@ -110,7 +109,7 @@ class TestUtils(designate.tests.TestCase):
     def test_from_dnspython_zone_no_soa(self):
         zone_file = self.get_zonefile_fixture(variant='nosoa')
 
-        dnspython_zone = dnszone.from_text(
+        dnspython_zone = dns.zone.from_text(
             zone_file,
             relativize=False,
             check_origin=False
@@ -125,7 +124,7 @@ class TestUtils(designate.tests.TestCase):
     def test_parse_zone(self):
         zone_file = self.get_zonefile_fixture()
 
-        dnspython_zone = dnszone.from_text(
+        dnspython_zone = dns.zone.from_text(
             zone_file,
             # Don't relativize, otherwise we end up with '@' record names.
             relativize=False,
