@@ -21,18 +21,10 @@ stop_process designate-api
 stop_process designate-mdns
 stop_process designate-agent
 stop_process designate-sink
-if is_service_enabled designate-worker; then
-    stop_process designate-worker
-    stop_process designate-producer
-else
-    stop_process designate-pool-manager
-    stop_process designate-zone-manager
-fi
+stop_process designate-worker
+stop_process designate-producer
+
 
 # sanity check that service is actually down
-ensure_services_stopped designate-api designate-central designate-mdns designate-agent designate-sink
-if is_service_enabled designate-worker; then
-    ensure_services_stopped designate-worker designate-producer
-else
-    ensure_services_stopped designate-pool-manager designate-zone-manager
-fi
+ensure_services_stopped designate-api designate-central designate-mdns designate-agent designate-sink designate-worker designate-producer
+
